#include <LPC214x.h>
#include "lcd.h"
#include "timer.h"
#include "PCD8544.h"
#include "music.h"
#include <stdlib.h>
#include <stdio.h>


//definitions for captain lark
#define HERO_WIDTH 10
#define HERO_HEIGHT 7
#define FRAME_COL 84
#define FRAME_BANK 6
#define FRAME_ROW 48
#define WALL_WIDTH 4
#define WALL_HEIGHT 48
#define NO_OF_WALL_STATES 6
#define BULLET_WIDTH 4
#define BULLET_HEIGHT 3
#define HERO_POSITION 40

//definitions for falcon 

#define SHIP_WIDTH 10
#define SHIP_HEIGHT 7
#define ENEMY_WIDTH 6
#define ENEMY_HEIGHT 6
#define ENEMY_ROW 4
#define ENEMY_COL 5
#define ENEMY_INTERVAL 2
#define ENEMY_XVEL 4
#define ENEMY_YVEL 2
#define LASER_HEIGHT 4
#define LASER_WIDTH 3

//definitions for PONG
#define BALL_WIDTH 5
#define BALL_HEIGHT 5
#define PADDLE_WIDTH 15
#define PADDLE_HEIGHT 4
#define REACTION_TIME 5




//general loop variables
int i, j;

//initializations common to all games

//initialize the binary frame buffer in RAM
unsigned char binaryFrame[48][84];

//initialize the byte organized frame buffer in RAM
unsigned char frame[6][84];

//Number Fonts

const unsigned char font_bmp[10][8][6] = {

{
{0,0,1,1,1,0},
{0,1,0,0,0,1},
{0,1,0,0,1,1},
{0,1,0,1,0,1},
{0,1,1,0,0,1},
{0,1,0,0,0,1},
{0,0,1,1,1,0},
{0,0,0,0,0,0}
},


{
{0,0,0,1,0,0},
{0,0,1,1,0,0},
{0,0,0,1,0,0},
{0,0,0,1,0,0},
{0,0,0,1,0,0},
{0,0,0,1,0,0},
{0,0,1,1,1,0},
{0,0,0,0,0,0}
},

{
{0,0,1,1,1,0},
{0,1,0,0,0,1},
{0,0,0,0,0,1},
{0,0,0,0,1,0},
{0,0,0,1,0,0},
{0,0,1,0,0,0},
{0,1,1,1,1,1},
{0,0,0,0,0,0}
},

{
{0,1,1,1,1,1},
{0,0,0,0,1,0},
{0,0,0,1,0,0},
{0,0,0,0,1,0},
{0,0,0,0,0,1},
{0,1,0,0,0,1},
{0,0,1,1,1,0},
{0,0,0,0,0,0}
},

{
{0,0,0,0,1,0},
{0,0,0,1,1,0},
{0,0,1,0,1,0},
{0,1,0,0,1,0},
{0,1,1,1,1,1},
{0,0,0,0,1,0},
{0,0,0,0,1,0},
{0,0,0,0,0,0}
},

{
{0,1,1,1,1,1},
{0,1,0,0,0,0},
{0,1,1,1,1,0},
{0,0,0,0,0,1},
{0,0,0,0,0,1},
{0,1,0,0,0,1},
{0,0,1,1,1,0},
{0,0,0,0,0,0}
},

{
{0,0,0,1,1,0},
{0,0,1,0,0,0},
{0,1,0,0,0,0},
{0,1,1,1,1,0},
{0,1,0,0,0,1},
{0,1,0,0,0,1},
{0,0,1,1,1,0},
{0,0,0,0,0,0}
},

{
{0,1,1,1,1,1},
{0,0,0,0,0,1},
{0,0,0,0,1,0},
{0,0,0,1,0,0},
{0,0,1,0,0,0},
{0,0,1,0,0,0},
{0,0,1,0,0,0},
{0,0,0,0,0,0}
},


{
{0,0,1,1,1,0},
{0,1,0,0,0,1},
{0,1,0,0,0,1},
{0,0,1,1,1,0},
{0,1,0,0,0,1},
{0,1,0,0,0,1},
{0,0,1,1,1,0},
{0,0,0,0,0,0}
},

{
{0,0,1,1,1,0},
{0,1,0,0,0,1},
{0,1,0,0,0,1},
{0,0,1,1,1,1},
{0,0,0,0,0,1},
{0,0,0,0,1,0},
{0,0,1,1,0,0},
{0,0,0,0,0,0}
}

};

void display_number(unsigned char x, unsigned char y, int number)
{
	for(i=0; i< 8; i++)
		for(j=0; j< 6; j++)
				{
					binaryFrame[y+i][x+j] = font_bmp[number][i][j];
				}
}

void display_score(unsigned char x, unsigned char y, unsigned char score)
{
	int temp ;
	temp = score / 10;
	display_number(x, y, temp);
	temp = score % 10;
	display_number(x+8, y, temp);

}



//common functions to all games

//converts the binary array to a byte organized array for writing to screen
void convertFrame(void)
{
	for(i=0; i<FRAME_BANK; i++)
		for(j=0; j<FRAME_COL; j++)
			frame[i][j] = 1 * binaryFrame[8*i][j] + 2 * binaryFrame[8*i+1][j] + 4 * binaryFrame[8*i+2][j] + 8* binaryFrame[8*i+3][j] 
						+ 16 * binaryFrame[8*i+4][j] + 32 * binaryFrame[8*i+5][j] + 64 * binaryFrame[8*i+6][j] + 128 * binaryFrame[8*i+7][j];
}


//clears binary array
void clearBinaryFrame(void)
{
	for(i=0; i<48; i++)
		for(j=0; j<84; j++)
			binaryFrame[i][j] = 0;

}

//draws a border on the screen
void draw_border()
{
	for(i=0;i<84;i++)
		binaryFrame[0][i] = 1;

	for(i=0;i<48;i++)
		binaryFrame[i][83] = 1;

	for(i=0;i<84;i++)
		binaryFrame[47][i] = 1;

	for(i=0;i<48;i++)
		binaryFrame[i][0] = 1;

}


//draws a full sized picture onto the screen
void draw_full(const unsigned char pic[48][84])
{
	for(i=0; i<48; i++)
		for(j=0;j<84;j++)
			binaryFrame[i][j] = pic[i][j];
}


struct ball
{
	unsigned char xcord;
	unsigned char ycord;
	int xvel;
	int yvel;
};

struct player_paddle
{
	unsigned char position;
	unsigned char score;

};

struct computer_paddle
{
	int position;
	unsigned char start;
	int ballPrediction;
	int hit_offset;
	unsigned char score;
};


//create two paddles and a ball
struct player_paddle player = {34, 0};
struct computer_paddle computer = {34, 5, 70, 2, 0};
struct ball myBall = {42,24,1,2};

//bitmap graphics for paddle and ball

const unsigned char paddle_bmp[PADDLE_HEIGHT][PADDLE_WIDTH] = {{1,1,1,1,1,1,1,1,1,1,1,1,1,1,1},
															   {1,1,1,1,1,1,1,1,1,1,1,1,1,1,1},
															   {1,1,1,1,1,1,1,1,1,1,1,1,1,1,1},
															   {1,1,1,1,1,1,1,1,1,1,1,1,1,1,1}};

const unsigned char ball_bmp[BALL_HEIGHT][BALL_WIDTH] = {{0,1,1,1,0},
														 {1,1,1,1,1},
														 {1,1,1,1,1},
														 {0,1,1,1,0}} ;


const unsigned char pongGameOver_bmp[48][84] = {
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,0,1,1,1,1,0,1,1,1,0,1,1,0,1,1,1,1,0,0,1,0,0,1,0,1,1,1,1,1,0,1,1,1,1,0,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,1,1,1,0,0,1,0,1,1,1,0,1,1,0,1,1,0,1,1,0,1,0,0,1,0,0,0,1,0,0,0,1,0,0,0,0,1,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,0,1,1,0,0,1,1,1,1,1,1,1,1,0,1,1,1,1,0,0,1,0,0,1,0,0,0,1,0,0,0,1,1,1,0,0,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,1,1,1,0,0,1,0,1,1,1,1,0,1,0,1,1,0,0,0,0,1,0,0,1,0,0,0,1,0,0,0,1,0,0,0,0,1,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,0,1,1,1,1,0,1,1,0,1,0,1,0,1,1,0,0,0,0,1,1,1,1,0,0,0,1,0,0,0,1,1,1,1,0,1,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,1,0,1,1,0,1,1,1,1,0,0,1,0,0,1,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,1,0,0,1,0,0,1,1,0,1,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,1,1,0,1,1,0,0,1,1,0,1,1,1,1,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,1,1,0,1,1,0,0,1,0,0,1,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,1,1,0,0,1,1,1,1,0,0,1,0,0,1,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,1,1,0,1,1,0,1,1,1,1,0,0,1,0,0,1,0,0,1,1,1,1,0,0,0,1,1,1,0,0,1,1,1,1,0,1,1,1,1,0,0,1,1,1,1,0,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,1,1,1,0,1,1,0,0,1,0,0,1,0,0,1,0,0,1,0,1,1,0,0,1,1,0,0,0,1,1,0,0,1,1,1,0,0,1,0,0,1,0,1,1,0,1,0,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,1,1,0,1,1,0,0,1,1,0,1,0,0,1,0,0,1,1,1,1,0,0,0,1,1,1,1,1,1,0,0,0,1,1,0,0,1,1,0,1,1,1,1,0,1,1,1,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,1,1,0,1,1,0,0,1,0,0,1,0,0,1,0,0,1,0,1,1,0,0,1,1,0,1,1,1,1,0,0,1,1,1,0,0,1,0,0,1,0,1,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,1,1,0,0,1,1,1,1,0,0,1,1,1,1,0,0,1,0,1,1,0,0,0,1,1,1,0,0,1,1,1,1,0,1,1,1,1,0,0,1,0,1,1,0,1,1,1,1,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}
};

//create the free movement update functions for all objects

int collision_wall()
{
	unsigned char buf[16] = {0};
	if( ((myBall.xcord == 78) && (myBall.xvel > 0)) || ((myBall.xcord ==5) && (myBall.xvel < 0) ))
		{
			myBall.xvel = 0-myBall.xvel;
			return 1;
		}
	else if((myBall.ycord == 42) && (myBall.yvel > 0)) 
		{
			myBall.yvel = 0-myBall.yvel;
			computer.score += 1;
			sprintf((char *)buf, "computer: %d", computer.score);
			lcd_clear();
			lcd_putstring(0,(char *)buf);
			sprintf((char *)buf, "player: %d", player.score);
			lcd_putstring(1,(char *)buf);
			return 1;
		}
	else if((myBall.ycord == 5) && (myBall.yvel < 0))
		{
			myBall.yvel = 0-myBall.yvel;
			player.score += 1;
			sprintf((char *)buf, "player: %d", player.score);
			lcd_clear();
			lcd_putstring(1,(char *)buf);
			sprintf((char *)buf, "computer: %d", computer.score);
			lcd_putstring(0,(char *)buf);
			return 1;
		}
	else
		return 0;
}

void pongGameOver()
{
	if(computer.score >= 5)
	{
		draw_full(pongGameOver_bmp);
		display_score(65, 33, player.score);
		draw_border();
		convertFrame();
		PCD8544_fill(frame); 
		playGameOver();
		while(1)
			;

	}
}
int collision_player()
{	
	if((myBall.xcord + 2 >= player.position) && (myBall.xcord + 2 <= player.position + 15))
	{

	if (myBall.xcord + 2 <= (player.position + 2))
	{
		myBall.xvel = -3;
		myBall.yvel = 0 - myBall.yvel;
		return 1;
	}
	else if (myBall.xcord + 2 <= (player.position + 4))
	{
		myBall.xvel = -2;
		myBall.yvel = 0 - myBall.yvel;
		return 1;
	}
	else if (myBall.xcord + 2 <= (player.position + 8))
	{
		myBall.xvel = 0;
		myBall.yvel = 0 - myBall.yvel;
		return 1;
	}
	else if (myBall.xcord + 2 <= (player.position + 13))
	{
		myBall.xvel = 2;
		myBall.yvel = 0 - myBall.yvel;
		return 1;
	}
	else 
	{
		myBall.xvel = 3;
		myBall.yvel = 0 - myBall.yvel;
		return 1;
	}
	}
return 0;

}


int predict_trajectory()
{
	int temp ;

	
	temp = myBall.xcord + myBall.xvel * (myBall.ycord / 2) ;

	if(temp >= 83)
		return 83;
	else if(temp <= 0)
		return 0;
	else
		return temp;

}



int collision_computer()
{
	if((myBall.xcord + 2 >= computer.position) && (myBall.xcord + 2 <= computer.position + 15))
	{

	if (myBall.xcord + 2 <= (computer.position + 2))
	{
		myBall.xvel = -3;
		myBall.yvel = 0 - myBall.yvel;
		return 1;
	}
	if (myBall.xcord + 2 <= (computer.position + 4))
	{
		myBall.xvel = -2;
		myBall.yvel = 0 - myBall.yvel;
		return 1;
	}
	else if (myBall.xcord + 2 <= (computer.position + 8))
	{
		myBall.xvel = 0;
		myBall.yvel = 0 - myBall.yvel;
		return 1;
	}
	else if (myBall.xcord + 2 <= (computer.position + 13))
	{
		myBall.xvel = 2;
		myBall.yvel = 0 - myBall.yvel;
		return 1;
	}
	else 
	{
		myBall.xvel = 3;
		myBall.yvel = 0 - myBall.yvel;
		return 1;
	}
	}
	return 0;
}

void update_ball()
{	
	unsigned char flag = 0;
	//update positions first according to current velocity
	myBall.xcord = (myBall.xcord + myBall.xvel);
	myBall.ycord = (myBall.ycord + myBall.yvel);

	if( (myBall.xcord >= 78) && myBall.xvel > 0)
		myBall.xcord = 78;
	if((myBall.xcord <= 5) && myBall.xvel < 0)
		myBall.xcord = 5;
	if((myBall.ycord >= 42) && myBall.yvel > 0)
		myBall.ycord = 42;
	if((myBall.ycord <= 5) && myBall.yvel < 0)
		myBall.ycord = 5;

	//check for collision with either the walls or either of the paddles
	if(myBall.yvel < 0)
	{	
		if(myBall.ycord <= 7)
		if(collision_computer())
			flag = 1;
	}

	else if(myBall.yvel > 0)
	{
		if(myBall.ycord >= 40)
			if(collision_player())	
			{
				computer.start = REACTION_TIME ;
				computer.ballPrediction = predict_trajectory();
				computer.hit_offset = rand()%7; //(computer.hit_offset + 1)%7 ;
				flag = 1;
			}
	}

	if(collision_wall() && !flag)
	{
		computer.start = REACTION_TIME ;
		computer.ballPrediction = predict_trajectory();
		computer.hit_offset = rand()%7; //(computer.hit_offset + 1)%7 ;
	}

	flag = 0;

}


void update_computer()
{
	//ai to track the ball and keep position
	if(computer.start == 0)
	{
		if((computer.ballPrediction - (computer.position + 7)) > computer.hit_offset )
			computer.position = (computer.position+3)%84;
		else if((computer.ballPrediction - (computer.position + 7)) < 0 - computer.hit_offset )
			if(computer.position >= 3)
				computer.position -= 3;
			else
				computer.position = 0;
	}
	else
	{
		computer.start -= 1;
	}

}


//Now, we need to draw into the binary frame


void draw_player()
{
	for(i=0;i<PADDLE_WIDTH;i++)
		for(j=0;j<PADDLE_HEIGHT;j++)
			binaryFrame[44+j][player.position + i] = paddle_bmp[j][i];
}

void draw_computer()
{
	for(i=0;i<PADDLE_WIDTH;i++)
		for(j=0;j<PADDLE_HEIGHT;j++)
			binaryFrame[0+j][computer.position + i] = paddle_bmp[j][i];
}

void draw_ball()
{
	for(i=0; i<BALL_HEIGHT; i++)
		for(j=0; j<BALL_WIDTH; j++)
				binaryFrame[myBall.ycord+i][myBall.xcord+j] = ball_bmp[i][j];
}




//ISR for updateing sprites and animation
__irq void periodic_pong_ISR(void)
{	

	PCD8544_fill(frame); 	 //fill screen to new frame

	//take button input
	if(!(IOPIN0 & (1<<9)))
	{	
		if(player.position >= 65)
			player.position = 68;
		else
			player.position = player.position + 3;
	}

	if(!(IOPIN0 & (1<<3)))
	{	
		if(player.position <= 3)
			player.position = 0;
		else
			player.position = player.position - 3;
	}



//updates ball 	
update_ball();



//updates computer paddle position
update_computer();

pongGameOver();
	
//Now we need to redraw the frame with updated lark.position
	
	//first clear the frame_buffer
	clearBinaryFrame();

	//draw border
	draw_border();

	 //draw ball
	draw_ball();

	//draw paddles 
	draw_player();
	draw_computer();

	//convert binaryFrame to organized
	convertFrame();


	T0IR |= 1<<0;
	
	VICVectAddr = 0;	
}



//ISR for right button connected to EINT 1
__irq void right_ISR(void)
{	
	 player.position += 3;

	//resets interrupt
	EXTINT |= (1<<1);
	VICVectAddr = 0; 
}

//ISR for shoot button
__irq void left_ISR(void)
{	
	player.position -= 1;

	//resets interrupt
	EXTINT |= (1<<3);
	VICVectAddr = 0;
}








int pong_main()
{	
	init_lcd();
	PCD8544_init();
	lcd_clear();
	lcd_putstring(0,"welcome to pong");

	
	//clear the frame_buffer
	for(i=0;i<6;i++)
		for(j=0;j<84;j++)
			frame[i][j] = 0x00;

	//first clear the frame_buffer
	clearBinaryFrame();

	 //draw paddles
	draw_player();
	draw_computer();

	//draw ball 
	draw_ball();

	//convert binaryFrame to organized
	convertFrame();

	PCD8544_fill(frame); 	 //fill screen to new frame

	lcd_clear();
	lcd_putstring(0,"computer: 0");
	lcd_putstring(1,"player: 0");

	//set up interrupts for the timer
	VICIntSelect &= ~(1<<4);
	VICVectAddr5 = (unsigned int)periodic_pong_ISR;
	VICVectCntl5 = (1<<5) | 4;
	VICIntEnable = (1<<4);


	
	//configure external interrupts
	// EINT1, EINT2 and EINT3 are used

	//edge sesitivity for all interrupts	
	EXTMODE = (1<<1) | (1<<3);
					  
	//Set negative edge sensitivity for all EINTs
	EXTPOLAR &= ~((1<<1) | (1<<3) ) ;


   	//Configure pinselect block for all three interrupts  at pins 9, 3 and 15
	PINSEL0 |= 0x800C00C0;
	
	//VIC config for EINT1
	VICIntSelect &= ~(1<<15);
	VICVectAddr7 = (unsigned int)right_ISR;
	VICVectCntl7 = (1<<5) | 15;
	VICIntEnable |= (1<<15);


	//VIC config for EINT3
	VICIntSelect &= ~(1<<17);
	VICVectAddr8 = (unsigned int)left_ISR;
	VICVectCntl8 = (1<<5) | 17;
	VICIntEnable |= (1<<17);

	//Reset all interrupt flags
	EXTINT &= ~((1<<1) | (1<<3) );
	

	//configure pins P0.9 and P0.3 for input
	IODIR0  &= ~((1<<9) | (1<<3) ) ;


	initTimer0();
	initTimer1();

	while(1);



	return 0;
}





//data structures for the game sprites

struct ship
{
	unsigned char position;
	unsigned char score;
};

struct laser
{
	unsigned char xcord;
	unsigned char ycord;
	unsigned char active;
};



//instantiate the game sprites 
struct ship falcon = {40, 0};

//instantiate a weapon
struct laser myLaser = {0,0,0};


//array of enemies
unsigned char enemy[ENEMY_ROW][ENEMY_COL] = {
											{1,1,1,1,1},
											{1,0,0,1,1},
											{1,1,1,1,1},
											{1,1,1,1,1}
											};

//position of the enemy array
int enemy_xcord;
int enemy_ycord;




//graphics for the game sprites
const unsigned char ship_bmp[SHIP_HEIGHT][SHIP_WIDTH] = {
						   {0,0,0,0,1,1,0,0,0,0},
						   {0,0,0,0,1,1,0,0,0,0},
						   {0,0,0,1,1,1,1,0,0,0},
						   {0,0,1,1,1,1,1,1,0,0},
						   {0,1,1,1,1,1,1,1,1,0},
						   {1,1,1,1,0,0,1,1,1,1},
						   {1,1,1,1,0,0,1,1,1,1}
						   };


const unsigned char enemy_bmp[ENEMY_HEIGHT][ENEMY_WIDTH] = {
							{1,0,0,0,0,1},
							{1,1,0,0,1,1},
							{1,1,1,1,1,1},
							{1,0,1,1,0,1},
							{1,1,1,1,1,1},
							{0,0,1,1,0,0}
							
};

void draw_ship()
{
	for(i=0; i<SHIP_HEIGHT; i++)
		for(j=0; j<SHIP_WIDTH; j++)
				binaryFrame[39+i][falcon.position+j] = ship_bmp[i][j];
}


//function to draw individual enemy sprite 
void draw_enemy_sprite(int xcord, int ycord)
{
	int m, n;
	for(m=0; m<ENEMY_HEIGHT; m++)
		for(n=0; n<ENEMY_WIDTH; n++)
				binaryFrame[xcord +m][ycord +n] = enemy_bmp[m][n];
}

//function to draw enemy array
void draw_enemy_array()
{
	for(i=0;i<ENEMY_ROW; i++)
		for(j=0;j<ENEMY_COL; j++)
			if(enemy[i][j] == 1)
				draw_enemy_sprite(enemy_ycord + i*(ENEMY_WIDTH + ENEMY_INTERVAL), enemy_xcord + j*(ENEMY_HEIGHT + ENEMY_INTERVAL));

			
}

const unsigned laser_bmp[LASER_HEIGHT][LASER_WIDTH] = { {0,1,0},
														{0,1,0},
														{1,1,1},
														{1,1,1}
													};

void draw_laser()
{	

	for(i=0; i<LASER_HEIGHT; i++)
		for(j=0; j<LASER_WIDTH; j++)
				binaryFrame[myLaser.ycord + i][myLaser.xcord+j] = laser_bmp[i][j];

}



//some variables to keep track of the enemy status
unsigned char enemy_move;
int enemy_velocity;
unsigned char enemy_arrayHeight;


//function to move enemy 
void update_enemy()
{
	if(enemy_move == 5)
	{	
		enemy_xcord = enemy_xcord + enemy_velocity;

		if(enemy_xcord > (83 - ENEMY_COL*(ENEMY_WIDTH + ENEMY_INTERVAL)))
		{
			enemy_xcord = (80 - ENEMY_COL*(ENEMY_WIDTH + ENEMY_INTERVAL));
			enemy_velocity = 0-ENEMY_XVEL;
			enemy_ycord += ENEMY_YVEL;
		}
		else if(enemy_xcord < 2)
		{
			enemy_xcord = 0;
			enemy_velocity = ENEMY_XVEL;
			enemy_ycord += ENEMY_YVEL;
		}
		enemy_move = 0;
	}
	else
	{
		enemy_move += 1;
	}
}

void laser_move()
{
	if(myLaser.ycord == 0)
		myLaser.active = 0;
	else
		myLaser.ycord -= 3;
}


void update_laser(struct laser *myLaser)
{	
	if((myLaser->xcord >= enemy_xcord) && ( myLaser->xcord <= enemy_xcord + ENEMY_COL*(ENEMY_WIDTH + ENEMY_INTERVAL)))				
	{	
		unsigned char col_number  = (myLaser->xcord - enemy_xcord)/8;
		unsigned char row_number = (myLaser->ycord - enemy_ycord)/8;

		if((myLaser->ycord - enemy_ycord) >= ENEMY_ROW*(ENEMY_HEIGHT + ENEMY_INTERVAL))
		{   
			laser_move();
			return;
		}
        if(enemy[row_number][col_number] == 0)
			laser_move();
		else
		{
			enemy[row_number][col_number] = 0;
			falcon.score++;
			myLaser->active = 0;
		}
	}
	else
	laser_move();
		
	
}



//ISR for shoot button
__irq void zoom_ISR(void)
{	

	if(!myLaser.active)
	{	
		playToneShoot();
		myLaser.xcord = falcon.position + 3;
		myLaser.ycord = 72;
		myLaser.active = 1;
	}

	//resets interrupt
	EXTINT |= (1<<2);
	VICVectAddr = 0;
}

void falcon_gameOver()
{
	draw_full(pongGameOver_bmp);
	display_score(65, 33, falcon.score);
	draw_border();
	convertFrame();
	PCD8544_fill(frame); 
	playGameOver();

	while(1)
		;

}

void falcon_gameOverCheck()
{	
	unsigned char bottom_row = ENEMY_ROW - 1;
	unsigned char flag;

	for(i= ENEMY_ROW - 1; i>=0; i--)
		{
			for(j=0; j< ENEMY_COL; j++)
				if(enemy[i][j] == 1)
				{
					flag = 1;
					break;
				}
			if(flag==1)
			{
				bottom_row = i;
				break;
			}
		}
	if(flag == 1) 
	{
		if(enemy_ycord + (bottom_row +1)*(ENEMY_HEIGHT+ ENEMY_INTERVAL) >= 40)
			falcon_gameOver();
	}	
		
	else 
	{
		lcd_clear();
		lcd_putstring(0, "YOU WON!!");
	}
}



//ISR for updateing sprites and animation
__irq void periodic_falcon_ISR(void)
{	

	PCD8544_fill(frame); 	 //fill screen to new frame

	//take button input to update falcon
	if(!(IOPIN0 & (1<<9)))
		if(falcon.position >= 70)
			falcon.position = 73;
		else
			falcon.position = (falcon.position + 3);

	if(!(IOPIN0 & (1<<3)))
	{	
		if(falcon.position >= 3)
		falcon.position -= 3;
		else
			falcon.position = 0;
	}


//update the enemy sprites
update_enemy();

if(myLaser.active)
	update_laser(&myLaser);

falcon_gameOverCheck();

	
//Now we need to redraw the frame with updated positions
	
	//first clear the frame_buffer
	clearBinaryFrame();

	//draw falcon
	draw_ship();

	//draw_enemy_array
	draw_enemy_array();

	if(myLaser.active)
	draw_laser();

	//draw border
	draw_border();
	

	//convert binaryFrame to organized
	convertFrame();

	
	T0IR |= 1<<0;
	
	VICVectAddr = 0;


}



int falcon_main(void)
{	


	init_lcd();
	PCD8544_init();
	lcd_clear();
	lcd_putstring(0,"welcome AI");


	//set up interrupts for the timer
	VICIntSelect &= ~(1<<4);
	VICVectAddr5 = (unsigned int)periodic_falcon_ISR;
	VICVectCntl5 = (1<<5) | 4;
	VICIntEnable = (1<<4);

	//configure pins P0.9 and P0.3 for input
	IODIR0  &= ~((1<<9) | (1<<3) );

EXTMODE = 0x4;
 EXTPOLAR &= ~(0x4);
 PINSEL0 |= 0x80000000;
 VICIntSelect &= ~ (1<<16); // EINT2 selected as IRQ 16
 VICVectAddr6 = (unsigned int)zoom_ISR; // address of the ISR
 VICVectCntl6 = (1<<5) | 16; //
 VICIntEnable |= (1<<16); // EINT2 interrupt enabled

 EXTINT &= ~(0x4); 


	//initialize enemy array coordinates
	enemy_xcord = 10;
	enemy_ycord = 5;
	enemy_move = 0;
	enemy_velocity = ENEMY_XVEL;

    initTimer0();
	initTimer1();


	while(1)
		;

	return 0;
}



// CAPTAIN LARK CODE


struct hero
{
	unsigned char position;
	unsigned char jump;
	signed char velocity;
	unsigned char velocityRate;
	unsigned char score;

};


enum wall_state
{
	open1, open2, open3, closed1, closed2, closed3
};


//data struct for wall variable
struct wall
{
	unsigned char position;
	enum wall_state state;
};

//structure for bullet
struct bullet
{
	unsigned char row;
	unsigned char col;
	unsigned char active;
};



//instantiate all your required variables


//hero captain lark
struct hero lark = {20,0,0,0,0};

//instantiate bullet 
struct bullet myBullet = {0,0,0};

//instantiate two wall objects , initialize in main
struct wall wall1, wall2;

//Initialization for the wall objects called in main()
void wall_init()
{
   wall1.position = 80;
   wall1.state    = rand()%5 ;
   wall2.position = 36;
   wall2.state    = rand()%5 ;
}




const unsigned char hero_bmp[8][10] ={
								  {0,0,1,1,1,1,0,0,0,0}, 
								  {0,1,1,1,1,1,1,0,0,0}, 
								  {1,1,1,1,0,0,1,1,0,0}, 
								  {1,1,1,1,0,0,1,1,0,0},
								  {1,1,1,1,1,1,1,1,1,0}, 
								  {0,1,1,1,1,1,1,1,1,1}, 
							      {0,0,1,1,1,1,0,0,0,0}
								  };


const unsigned char wall_bmp[WALL_HEIGHT][NO_OF_WALL_STATES * WALL_WIDTH] = 
{
{1,1,1,1,0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1},
{1,1,1,1,0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1},
{1,1,1,1,0,0,0,0,1,1,1,1,1,1,1,1,0,0,0,0,1,1,1,1},
{1,1,1,1,0,0,0,0,1,1,1,1,1,1,1,1,0,0,0,0,1,1,1,1},
{1,1,1,1,0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1},
{1,1,1,1,0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1},
{1,1,1,1,0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1},
{1,1,1,1,0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1},
{1,1,1,1,0,0,0,0,1,1,1,1,1,1,1,1,0,0,0,0,1,1,1,1},
{1,1,1,1,0,0,0,0,1,1,1,1,1,1,1,1,0,0,0,0,1,1,1,1},
{1,1,1,1,0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1},
{1,1,1,1,0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1},
{1,1,1,1,0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1},
{1,1,1,1,0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1},
{1,1,1,1,0,0,0,0,1,1,1,1,1,1,1,1,0,0,0,0,1,1,1,1},
{1,1,1,1,0,0,0,0,1,1,1,1,1,1,1,1,0,0,0,0,1,1,1,1},
{0,0,0,0,1,1,1,1,1,1,1,1,0,0,0,0,1,1,1,1,1,1,1,1},
{0,0,0,0,1,1,1,1,1,1,1,1,0,0,0,0,1,1,1,1,1,1,1,1},
{0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1},
{0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1},
{0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1},
{0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1},
{0,0,0,0,1,1,1,1,1,1,1,1,0,0,0,0,1,1,1,1,1,1,1,1},
{0,0,0,0,1,1,1,1,1,1,1,1,0,0,0,0,1,1,1,1,1,1,1,1},
{0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1},
{0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1},
{0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1},
{0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1},
{0,0,0,0,1,1,1,1,1,1,1,1,0,0,0,0,1,1,1,1,1,1,1,1},
{0,0,0,0,1,1,1,1,1,1,1,1,0,0,0,0,1,1,1,1,1,1,1,1},
{0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1},
{0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1},
{1,1,1,1,1,1,1,1,0,0,0,0,1,1,1,1,1,1,1,1,0,0,0,0},
{1,1,1,1,1,1,1,1,0,0,0,0,1,1,1,1,1,1,1,1,0,0,0,0},
{1,1,1,1,1,1,1,1,0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1},
{1,1,1,1,1,1,1,1,0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1},
{1,1,1,1,1,1,1,1,0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1},
{1,1,1,1,1,1,1,1,0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1},
{1,1,1,1,1,1,1,1,0,0,0,0,1,1,1,1,1,1,1,1,0,0,0,0},
{1,1,1,1,1,1,1,1,0,0,0,0,1,1,1,1,1,1,1,1,0,0,0,0},
{1,1,1,1,1,1,1,1,0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1},
{1,1,1,1,1,1,1,1,0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1},
{1,1,1,1,1,1,1,1,0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1},
{1,1,1,1,1,1,1,1,0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1},
{1,1,1,1,1,1,1,1,0,0,0,0,1,1,1,1,1,1,1,1,0,0,0,0},
{1,1,1,1,1,1,1,1,0,0,0,0,1,1,1,1,1,1,1,1,0,0,0,0},
{1,1,1,1,1,1,1,1,0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1},
{1,1,1,1,1,1,1,1,0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1}
};

const unsigned char splash_screen[48][84] = {
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,1,0,0,0,0,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,0,0,0,0,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,0,0,0,0,0,0,0,0,0},
{1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,0,0,0,0,0},
{0,0,0,0,1,1,1,0,0,0,0,1,1,1,0,0,0,1,1,1,1,0,1,1,1,1,1,1,0,0,1,1,1,0,0,0,1,1,0,0,1,1,0,0,1,1,0,0,0,0,1,1,0,0,0,0,0,1,1,1,0,0,0,1,1,1,1,0,0,0,1,1,0,0,1,1,0,0,1,1,1,1,1,1},
{0,0,0,1,1,1,1,1,0,0,0,1,1,1,0,0,0,1,1,1,1,1,1,1,1,1,1,1,0,0,1,1,1,0,0,0,1,1,0,0,1,1,1,0,1,1,0,0,0,0,1,1,0,0,0,0,0,1,1,1,0,0,0,1,1,1,1,1,0,0,1,1,0,1,1,0,0,0,0,0,0,0,0,0},
{0,0,0,1,1,0,1,1,0,0,1,1,0,1,1,0,0,1,1,0,1,1,0,0,1,1,0,0,0,1,1,0,1,1,0,0,1,1,0,0,1,1,1,0,1,1,0,0,0,0,1,1,0,0,0,0,1,1,0,1,1,0,0,1,1,0,1,1,0,0,1,1,1,1,0,0,0,0,0,0,0,0,0,0},
{0,0,0,1,1,0,0,0,0,0,1,1,0,1,1,0,0,1,1,1,1,1,0,0,1,1,0,0,0,1,1,0,1,1,0,0,1,1,0,0,1,1,1,1,1,1,0,0,0,0,1,1,0,0,0,0,1,1,0,1,1,0,0,1,1,1,1,1,0,0,1,1,1,1,1,0,0,0,0,0,0,0,0,0},
{0,0,0,1,1,0,1,1,0,0,1,1,1,1,1,0,0,1,1,1,1,0,0,0,1,1,0,0,0,1,1,1,1,1,0,0,1,1,0,0,1,1,0,1,1,1,0,0,0,0,1,1,0,0,0,0,1,1,1,1,1,0,0,1,1,1,1,0,0,0,1,1,0,0,1,1,0,0,0,0,0,0,0,0},
{0,0,0,1,1,1,1,1,0,1,1,1,1,1,1,1,0,1,1,0,0,0,0,0,1,1,0,0,1,1,1,1,1,1,1,0,1,1,0,0,1,1,0,1,1,1,0,0,0,0,1,1,1,1,0,1,1,1,1,1,1,1,0,1,1,0,1,1,0,0,1,1,0,0,1,1,0,0,0,0,0,0,0,0},
{0,0,0,0,1,1,1,0,0,1,1,0,0,0,1,1,0,1,1,0,0,0,0,0,1,1,0,0,1,1,0,0,0,1,1,0,1,1,0,0,1,1,0,0,1,1,0,0,0,0,1,1,1,1,0,1,1,0,0,0,1,1,0,1,1,0,0,1,1,0,1,1,0,0,0,1,1,1,1,1,1,1,1,1},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,0,0,0,0,0,0,0,0},
{0,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,0,0,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1,1,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,1,1,1,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,1,1,0,0,0,0,0,0,0,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,1,1,1,0,0,0,0,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,0,0,0,0,0,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,1,1,1,1,0,0,1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1,0,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,0,0,0,1,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,0,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,1,1,0,1,1,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,1,0,1,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,1,1,1,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,0,0,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,1,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,1,0,0,0,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,0,0,0,0,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,0,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,0,0,0,0,0,0,0},
{0,0,0,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,0,0,1,0,0,0,0,0,0},
{0,0,1,0,1,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,1,0,0,0,0,0},
{0,1,0,0,0,0,0,0,0,1,0,0,0,1,1,1,0,1,1,1,0,0,1,1,0,0,1,1,0,0,1,1,0,0,0,1,1,1,1,0,1,1,1,0,0,0,0,1,1,0,1,1,1,1,0,0,1,0,0,0,1,1,1,0,1,1,1,1,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0},
{0,1,1,0,0,0,0,0,1,0,0,0,0,1,0,1,0,1,0,1,0,0,1,0,0,1,1,0,0,1,1,0,0,0,0,0,1,1,0,1,1,0,0,1,0,0,1,1,0,0,0,1,1,0,0,1,0,1,0,0,1,0,1,0,0,1,1,0,0,0,1,0,0,0,0,0,0,1,0,0,0,0,0,0},
{0,0,1,1,1,1,1,1,0,0,0,0,0,1,1,1,0,1,1,1,0,0,1,1,0,0,1,1,0,0,1,1,0,0,0,0,1,1,0,1,0,0,0,1,0,0,0,1,1,0,0,1,1,0,0,1,0,1,0,0,1,1,1,0,0,1,1,0,0,0,0,1,0,1,0,1,1,0,0,0,0,0,0,0},
{0,0,1,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,1,1,0,0,1,0,0,0,0,1,1,0,0,1,1,0,0,0,1,1,0,1,1,0,0,1,0,0,0,0,1,1,0,1,1,0,0,1,1,1,0,0,1,1,1,0,0,1,1,0,0,0,0,1,1,0,1,1,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,1,0,0,1,1,1,1,1,1,0,1,1,1,0,0,0,0,1,1,0,0,1,1,1,0,0,0,1,1,1,0,0,1,1,0,1,0,0,0,1,0,1,0,1,0,0,1,1,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}
};


const unsigned char game_over_bmp[48][84] = {
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{1,1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{1,1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,0,1,1,1,0,0,0,0,1,1,0,0,0,1,1,0,0,1,1,0,0,1,1,1,1,0,0,0,0,0,0,0},
{1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,1,1,0,1,1,0,0,0,1,1,1,0,0,1,1,0,1,1,1,0,0,1,1,1,1,0,0,0,0,0,0,0},
{0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,1,1,0,0,0,0,0,0,1,1,1,1,0,0,1,1,0,1,0,1,0,0,1,1,1,1,0,0,0,0,0,0,0},
{0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,1,1,1,0,0,0,1,1,0,1,1,1,0,0,1,1,0,1,0,0,1,1,1,1,0,1,0,0,1,1,1,1,0,0,0,0,0,0,0},
{0,0,0,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,1,0,0,0,0,0,1,1,0,0,1,0,0,1,1,1,1,1,0,1,0,1,1,0,1,0,0,1,0,0,0,0,0,0,0,0,0,0},
{0,0,0,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,1,1,0,0,0,0,1,1,1,1,1,0,1,1,0,0,1,1,0,1,0,1,1,0,1,0,0,1,1,1,1,0,0,0,0,0,0,0},
{0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,0,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,1,1,0,0,0,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,1,1,1,0,1,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,1,1,0,0,0,0,1,1,0,0,1,1,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,1,1,0,0,0,0,1,0,0,1,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,1,1,0,0,0,0,1,0,1,1,0,0,1,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,0,0,0,0,1,1,1,0,0,1,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,1,1,0,0,0,0,0,0,1,0,0,0,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,1,0,1,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,1,1,0,0,0,0,0,0,1,0,0,0,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,1,0,1,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,1,1,0,0,0,0,0,0,1,0,0,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,1,1,1,1,0,0,0,1,1,1,0,1,1,0,1,0,0,0,1,0,0,0,0,0,1,1,1,0,0,1,1,0,0,1,1,0,1,1,1,1,0,0,1,1,1,1,0,1,1,0,0,0,0},
{0,0,0,0,0,1,1,0,0,0,0,0,1,0,0,1,1,1,1,0,1,1,1,0,0,0,0,1,0,1,1,0,0,0,0,1,1,1,1,1,1,1,1,1,0,1,0,0,0,1,0,0,0,0,1,1,1,1,1,0,1,1,0,0,1,1,0,1,1,1,1,0,0,1,0,0,1,1,1,1,0,0,0,0},
{0,0,0,0,0,0,0,1,1,0,0,0,1,0,0,1,1,1,1,0,0,1,1,1,1,1,1,0,1,0,0,0,0,0,0,0,0,1,0,1,1,1,0,0,0,0,0,0,0,1,1,0,0,1,1,0,0,1,1,0,0,1,1,0,1,0,0,1,1,1,1,0,0,1,0,0,1,1,0,1,0,0,0,0},
{0,0,0,0,0,0,0,1,1,0,0,0,1,0,0,0,1,1,1,1,1,1,1,0,1,0,0,1,1,0,0,0,0,0,0,0,0,0,1,0,0,0,0,1,1,0,0,1,1,1,0,0,0,1,1,0,0,0,1,0,0,1,1,1,1,0,0,1,1,1,1,0,0,1,1,1,0,0,0,1,0,0,0,0},
{0,0,0,0,0,0,1,1,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,1,0,0,0,0,0,0,0,0,0,1,1,0,0,0,0,0,0,1,0,0,0,0,0,0,1,1,0,1,1,0,0,0,1,1,1,0,0,1,0,0,0,0,0,1,0,1,1,0,0,0,0,0,0,0},
{0,0,0,0,0,1,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,1,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,1,1,1,1,0,0,0,0,1,1,0,0,0,1,1,1,1,0,0,1,0,0,1,1,0,1,0,0,0,0},
{0,0,0,0,0,0,0,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,0,0,0,0,0,1,1,0,0,0,1,1,0,0,0,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,0,0,0,0,0,0,0,1,0,0,1,1,1,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,1,1,1,1,1,0,0,1,1,1,1,1,1,1,1,1,0,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,1,1,0,1,1,0,0,0,0,0,1,1,1,1,1,0,1,1,0,0,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,1,1,0,0,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,0,0,0,0,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,1,1,0,0,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,0,0,0,0,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,1,1,0,1,1,1,1,0,1,1,1,1,1,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,0,0,0,0,0,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,1,1,1,0,1,1,1,1,0,0,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,1,1,1,1,1,1,1,1,0,0,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,1,1,1,1,1,1,1,1,0,1,1,1,1,1,1,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,1,1,0,1,1,1,0,1,1,1,1,1,1,1,0,0,0,0,0,1,0,0,1,0,0,0,0,0,0,0,0,0,0,1,0,1,1,0,0,0,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{1,1,0,0,1,1,0,0,1,1,1,0,0,0,1,0,0,1,1,0,0,0,0,0,1,1,1,0,0,0,0,1,1,1,0,0,0,1,1,1,0,0,0,1,1,1,1,0,0,1,1,1,1,0,0,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,1,1,0,1,0,0,1,1,1,1,1,0,0,1,0,0,1,1,0,0,0,0,0,1,0,1,1,0,0,1,1,1,1,1,0,1,1,1,1,1,0,0,1,0,0,1,1,0,1,1,1,1,0,0,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,1,1,1,0,1,1,0,0,1,1,0,0,1,0,0,1,1,0,0,0,0,0,1,1,1,0,0,1,1,0,0,0,0,1,1,0,0,1,1,0,0,1,0,0,1,1,0,1,1,1,1,0,0,1,0,0,1,1,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,1,1,0,0,1,1,0,0,0,1,0,0,1,0,0,1,1,0,0,0,0,0,0,1,1,1,0,1,1,0,0,0,0,1,1,0,0,0,1,0,0,1,1,1,0,0,0,1,1,1,1,0,0,1,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,1,1,0,0,0,1,1,0,1,1,0,0,1,1,0,1,1,0,0,0,0,1,1,0,0,1,0,0,1,1,0,1,1,0,1,1,0,1,1,0,0,1,0,1,1,0,0,1,0,0,0,0,0,1,0,0,1,1,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,1,1,0,0,0,1,1,1,1,0,0,0,1,1,1,1,0,0,0,0,0,0,1,1,1,1,0,0,1,1,1,1,0,0,1,1,1,1,0,0,0,1,0,0,1,1,0,1,1,1,1,0,0,1,1,1,1,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}
};



const unsigned bullet_bmp[BULLET_HEIGHT][BULLET_WIDTH] = {{1,1,1,0},
														  {1,1,1,1},
														  {1,1,1,0}};




void draw_bullet()
{	

	for(i=0; i<BULLET_HEIGHT; i++)
		for(j=0; j<BULLET_WIDTH; j++)
				binaryFrame[myBullet.row+i][myBullet.col+j] = bullet_bmp[i][j];

}



void draw_wall(struct wall* myWall)
{	
	//draw wall
	for(i=0;i<WALL_WIDTH; i++)
		for(j=0; j<WALL_HEIGHT;j++)
			binaryFrame[j][(myWall->position)+i] = wall_bmp[j][4*(myWall->state)+i];

}


void draw_hero(void)
{	

	for(i=0; i<HERO_HEIGHT; i++)
		for(j=0; j<HERO_WIDTH; j++)
				{
					if(hero_bmp[i][j] == 1);
					binaryFrame[lark.position+i][HERO_POSITION+j] = hero_bmp[i][j];
				}
}

void update_hero()
{
		if(lark.jump == 0)
	{
		
	 	if(lark.position >= 42)
		{
			lark.position = 42;
			lark.velocity = 1;
		}
		else
		{
			lark.position = lark.position+lark.velocity;
	 		if(lark.velocityRate==8)
	 		{
	 			lark.velocity = lark.velocity+1;
	 			lark.velocityRate =0;
	 		}
	 		else
			{
	 			lark.velocityRate +=1;
			} 	
	 
		}
	}

	else
	{
		if(lark.position <=1)
			lark.position = 0;
		else
			lark.position = lark.position-2;
		lark.jump -= 1;
	}

}

void update_wall(struct wall* myWall)
{	
	//updates wall1
	if(myWall->position > 0)
		myWall->position -= 1;
	else
	{
		myWall->position = 79;
		myWall->state = rand()%5;
	}

}



void wall_hit(struct wall* myWall)
{
	if((myBullet.col-myWall->position) <=4  && (myBullet.col-myWall->position) >=0)
			switch(myWall->state)
			{
				case 0: 
				{
					if((myBullet.row <= 16)||(myBullet.row >= 32))
						myBullet.active = 0;
					break;

				}
				case 1: 
				{
					if(myBullet.row >= 16)
						myBullet.active = 0;
					break;

				}
				case 2: 
				{
					if(myBullet.row <= 32)
						myBullet.active = 0;
					break;

				}
				case 3: 
				{
					if((myBullet.row <= 16)||(myBullet.row >= 32))
						myBullet.active = 0;
					else
					{
						myWall->state = 0;
						myBullet.active = 0;
					}
					break;

				}
				case 4: 
				{
					if(myBullet.row >= 16)
						myBullet.active = 0;
					else
					{
						myWall->state = 1;
						myBullet.active = 0;
					}
					break;

				}
				case 5: 
				{
					if(myBullet.row <= 32)
						myBullet.active = 0;
					else
					{
						myWall->state = 1;
						myBullet.active = 0;
					}
					break;

				}

			}	
}


//updates bullet coordinates and also wall and bullet states if bullet hit.
void update_bullet()
{
	if(myBullet.active)
	{
		myBullet.col += 1;
		wall_hit(&wall1);
		wall_hit(&wall2);
		
	}

}


void game_over()
{	
	draw_full(game_over_bmp);
	display_score(65, 39, lark.score);
	draw_border();
	convertFrame();
	PCD8544_fill(frame); 
	playGameOver();

	while(1)
		;

}	 


void check_gameOver()
{
	struct wall hitWall;
	unsigned char flag = 0;

	if( wall1.position == HERO_POSITION + 5)
	{
		hitWall = wall1;
		flag = 1;
	}
	else if (wall2.position == HERO_POSITION + 5)
	{
		hitWall = wall2;
		flag = 1;
	}

	if(flag)
	{
		switch(hitWall.state)
		{
			case 1 :
			{
				if(lark.position >= 11)
					game_over();
				else
					flag = 0;
				break;
			}

			case 0 :
			{
				if(lark.position <= 13 || lark.position >= 28)
					game_over();
				else
					flag = 0;
				break;
			}

			case 2 :
			{
				if(lark.position <= 28)
					game_over();
				else
					flag = 0;
				break;
			}

			default : 
			{
				game_over();
				break;
			}
		}
	}
}


//to keep score
unsigned char temp = 44;


//ISR for updateing sprites and animation
__irq void periodic_ISR(void)
{	

	PCD8544_fill(frame); 	 //fill screen to new frame

//updates lark 	
update_hero();


//update wall positions 
update_wall(&wall1);
update_wall(&wall2);

//updates bullet
update_bullet();

//check if game over
check_gameOver();

if(temp == 0)
{
	lark.score += 1;
	temp = 44;
}

else
	temp -= 1;


	
//Now we need to redraw the frame with updated lark.position
	
	//first clear the frame_buffer
	clearBinaryFrame();



	 //draw walls
	draw_wall(&wall1);
	draw_wall(&wall2);

	//draw hero 
	draw_hero();

	//draw bullet if active
	if(myBullet.active)
		draw_bullet();

		//first draw border
	draw_border();

	//convert binaryFrame to organized
	convertFrame();


	T0IR |= 1<<0;
	
	VICVectAddr = 0;	
}



//ISR for switch1 on the board connected to EINT2
__irq void sw1_ISR(void)
{	 lark.jump = 4;
	lark.velocity = 1;
	playToneJump();
	 EXTINT |= (1<<1) | (1<<2) | (1<<3);
	 VICVectAddr = 0;
}

//ISR for shoot button
__irq void shoot_ISR(void)
{	
	if(!myBullet.active)
	{
		playToneShoot();
		myBullet.col = HERO_POSITION;
		myBullet.row = lark.position;
		myBullet.active = 1;
	}

	//resets interrupt
	EXTINT |= (1<<3);
	VICVectAddr = 0;
}


int lark_main(void)
{	
	
   //initialize wall objects
   wall_init();


	init_lcd();
	PCD8544_init();
	lcd_clear();
	lcd_putstring(0,"hello jojo5");

/*
	IODIR0  &= ~((1<<9) | (1<<3) ) ;

	//first clear the frame_buffer
	clearBinaryFrame();



	//splash screen display
	draw_full(splash_screen);

		//draw border
	draw_border();

	//convert binaryFrame to organized
	convertFrame();

	PCD8544_fill(frame); 	 //fill screen to new frame


	while(((IOPIN0 & (1<<9)) && (IOPIN0 &(1<<3) )))
		;


	lcd_clear();
	lcd_putstring(0,"past menu");	

*/

	//set up interrupts for the timer
	VICIntSelect &= ~(1<<4);
	VICVectAddr5 = (unsigned int)periodic_ISR;
	VICVectCntl5 = (1<<5) | 4;
	VICIntEnable = (1<<4);

	//configure external interrupts
	// EINT1, EINT2 and EINT3 are used

	//edge sesitivity for all interrupts	
	EXTMODE = (1<<1) | (1<<2) | (1<<3);
					  
	//Set negative edge sensitivity for all EINTs
	EXTPOLAR &= ~((1<<1) | (1<<2) | (1<<3) ) ;

   	//Configure pinselect block for all three interrupts  at pins 9, 3 and 15
	PINSEL0 |= 0x800C00C0;
	
	//VIC config for EINT1
	VICIntSelect &= ~(1<<15);
	VICVectAddr7 = (unsigned int)sw1_ISR;
	VICVectCntl7 = (1<<5) | 15;
	VICIntEnable |= (1<<15);

	//VIC config for EINT2
	VICIntSelect &= ~(1<<16);
	VICVectAddr6 = (unsigned int)sw1_ISR;
	VICVectCntl6 = (1<<5) | 16;
	VICIntEnable |= (1<<16);

	//VIC config for EINT3
	VICIntSelect &= ~(1<<17);
	VICVectAddr8 = (unsigned int)shoot_ISR;
	VICVectCntl8 = (1<<5) | 17;
	VICIntEnable |= (1<<17);

	//Reset all interrupt flags
	EXTINT &= ~((1<<1) | (1<<2) | (1<<3) );

	initTimer0();
	initTimer1();

	
	 //playMelody();
	 
	while(1)
 	;

	return 0;

}



int main()
{
	init_lcd();
	lcd_clear();
	lcd_putstring(0,"lark: welcome");	
	initTimer1();

	PINSEL0 &= 0x00000000;
	IODIR0  &= ~((1<<9) | (1<<3) | (1<<15)) ;


	PCD8544_init();
	//first clear the frame_buffer
	clearBinaryFrame();



	//splash screen display
	draw_full(splash_screen);

		//draw border
	draw_border();

	//convert binaryFrame to organized
	convertFrame();

	PCD8544_fill(frame); 	 //fill screen to new frame

	playMelody();

	PINSEL0 &= 0x00000000;
	IODIR0  &= ~((1<<9) | (1<<3) | (1<<15)) ;

	while( (IOPIN0 & (1<<9)) && (IOPIN0 &(1<<3)) && (IOPIN0 & (1<<15) )  )
		;

	if(!(IOPIN0 & (1<<9)))
		lark_main();
	else if(!(IOPIN0 &(1<<3)))
		pong_main();
	else
		falcon_main();

	 
	while(1);

	return 0;
}



